django-jinja
============

Simple and nonobstructive jinja2 integration with Django.


.. image:: https://travis-ci.org/niwibe/django-jinja.png?branch=master
    :target: https://travis-ci.org/niwibe/django-jinja

.. image:: https://pypip.in/v/django-jinja/badge.png
    :target: https://crate.io/packages/django-jinja

.. image:: https://pypip.in/d/django-jinja/badge.png
    :target: https://crate.io/packages/django-jinja



**Documentation:** https://django-jinja.readthedocs.org/


How to install?
---------------

You can install it with pip:

.. code-block:: shell

    pip install django-jinja
